The Python package [esig](https://pypi.org/project/esig/) provides a toolset (previously called sigtools) for transforming vector time series in stream space to signatures in effect space. It is based on the [libalgebra](https://github.com/terrylyons/libalgebra) C++ library.

![build](https://github.com/datasig-ac-uk/esig/workflows/build/badge.svg)
